# xdist-scheduling-exclusive

Python logging handler for direct and efficient log transmission to 
OpenSearch. 

# Documentation

[API reference](api-reference/index.md)

# source code

[sorokin.engineer/xdist-scheduling-exclusive](https://github.com/andgineer/xdist-scheduling-exclusive)
